# Changelog

## 3.10.0 (2025-10-28)

Full Changelog: [v3.9.0...v3.10.0](https://github.com/WorqHat/worqhat-python-sdk/compare/v3.9.0...v3.10.0)

### Features

* **api:** manual updates ([4dd19dc](https://github.com/WorqHat/worqhat-python-sdk/commit/4dd19dc4ec0ffa46ce9a3e6bb0c18da0f241b399))

## 3.9.0 (2025-10-24)

Full Changelog: [v3.8.0...v3.9.0](https://github.com/WorqHat/worqhat-python-sdk/compare/v3.8.0...v3.9.0)

### Features

* **api:** manual updates ([586bf23](https://github.com/WorqHat/worqhat-python-sdk/commit/586bf230bbe49f665d3dfc5a5c01be30c6ae56c4))
* **api:** manual updates ([af79b06](https://github.com/WorqHat/worqhat-python-sdk/commit/af79b065dff0f6d7d41312f7c197f433a7ab5489))

## 3.8.0 (2025-10-19)

Full Changelog: [v3.7.0...v3.8.0](https://github.com/WorqHat/worqhat-python-sdk/compare/v3.7.0...v3.8.0)

### Features

* **api:** manual updates ([739f49d](https://github.com/WorqHat/worqhat-python-sdk/commit/739f49dbb213b8b9826fae95bf001f75e04c0935))

## 3.7.0 (2025-10-19)

Full Changelog: [v3.6.0...v3.7.0](https://github.com/WorqHat/worqhat-python-sdk/compare/v3.6.0...v3.7.0)

### Features

* **api:** manual updates ([b07d5df](https://github.com/WorqHat/worqhat-python-sdk/commit/b07d5df591f5bca1341c2f99e2b6843e04e8bba0))
* **api:** manual updates ([659b5c0](https://github.com/WorqHat/worqhat-python-sdk/commit/659b5c032e3a7599f722f9ae72065cb0dcdd78be))

## 3.6.0 (2025-10-18)

Full Changelog: [v3.5.2...v3.6.0](https://github.com/WorqHat/worqhat-python-sdk/compare/v3.5.2...v3.6.0)

### Features

* improve future compat with pydantic v3 ([c10590b](https://github.com/WorqHat/worqhat-python-sdk/commit/c10590b2bce24c0cb0bbb261d1dd9dabea8b44be))
* **types:** replace List[str] with SequenceNotStr in params ([d9c7c74](https://github.com/WorqHat/worqhat-python-sdk/commit/d9c7c74beb7f3326e2293601008811da6340bcd7))


### Bug Fixes

* avoid newer type syntax ([7120ba6](https://github.com/WorqHat/worqhat-python-sdk/commit/7120ba6e96144f1b6282fdca17d25efbf00cda32))


### Chores

* bump `httpx-aiohttp` version to 0.1.9 ([d248f43](https://github.com/WorqHat/worqhat-python-sdk/commit/d248f433ba1cdbc283c0372900c6882f12bd0c58))
* do not install brew dependencies in ./scripts/bootstrap by default ([e0e937e](https://github.com/WorqHat/worqhat-python-sdk/commit/e0e937e622d420dc4063a5acdda876f134f27a80))
* **internal:** add Sequence related utils ([bc4a714](https://github.com/WorqHat/worqhat-python-sdk/commit/bc4a7140a0d927fc7e176d36fd1833b38dfa13b1))
* **internal:** change ci workflow machines ([0232ab5](https://github.com/WorqHat/worqhat-python-sdk/commit/0232ab57ae1ed0473d593986942c3cdb79e2159d))
* **internal:** detect missing future annotations with ruff ([c129a5f](https://github.com/WorqHat/worqhat-python-sdk/commit/c129a5fb68d29ff4824321efd1f5880ed6cbf33b))
* **internal:** move mypy configurations to `pyproject.toml` file ([bd834ea](https://github.com/WorqHat/worqhat-python-sdk/commit/bd834ea2c5a254950f62575be8593404ca206d46))
* **internal:** update pydantic dependency ([c23539a](https://github.com/WorqHat/worqhat-python-sdk/commit/c23539a0119e514ee47b82fba53b4532e652e668))
* **internal:** update pyright exclude list ([84b9fd5](https://github.com/WorqHat/worqhat-python-sdk/commit/84b9fd58998c9507743483f9ed34c268ca636725))
* **tests:** simplify `get_platform` test ([0e66d79](https://github.com/WorqHat/worqhat-python-sdk/commit/0e66d79ec03d0f92a0326c6b6704270e2f4f3ba8))
* **types:** change optional parameter type from NotGiven to Omit ([ac83455](https://github.com/WorqHat/worqhat-python-sdk/commit/ac8345556584dc80a7b43af6838cad64710a4da8))

## 3.5.2 (2025-08-22)

Full Changelog: [v3.5.1...v3.5.2](https://github.com/WorqHat/worqhat-python-sdk/compare/v3.5.1...v3.5.2)

### Chores

* update github action ([8c4920b](https://github.com/WorqHat/worqhat-python-sdk/commit/8c4920b09863c837e0bbb0c32e953d60f4a2aaed))

## 3.5.1 (2025-08-12)

Full Changelog: [v3.5.0...v3.5.1](https://github.com/WorqHat/worqhat-python-sdk/compare/v3.5.0...v3.5.1)

### Chores

* **internal:** codegen related update ([74ed4ba](https://github.com/WorqHat/worqhat-python-sdk/commit/74ed4bade62baf731e65315962926cee86ed5fe9))
* **internal:** fix ruff target version ([1e8cf24](https://github.com/WorqHat/worqhat-python-sdk/commit/1e8cf2484d7181440f7cd080d5bc9f9db97cde07))
* **internal:** update comment in script ([7ea3a74](https://github.com/WorqHat/worqhat-python-sdk/commit/7ea3a7424d703bcf1711f57754f603c840777652))
* update @stainless-api/prism-cli to v5.15.0 ([3b18347](https://github.com/WorqHat/worqhat-python-sdk/commit/3b18347bd4c8bcd0ada7deead817fb9b3a7d2d59))

## 3.5.0 (2025-08-01)

Full Changelog: [v3.4.2...v3.5.0](https://github.com/WorqHat/worqhat-python-sdk/compare/v3.4.2...v3.5.0)

### Features

* **api:** update via SDK Studio ([601f909](https://github.com/WorqHat/worqhat-python-sdk/commit/601f9095e3e2f42875500711dc803ae756cf80bd))

## 3.4.2 (2025-07-31)

Full Changelog: [v3.4.1...v3.4.2](https://github.com/WorqHat/worqhat-python-sdk/compare/v3.4.1...v3.4.2)

## 3.4.1 (2025-07-31)

Full Changelog: [v3.4.0...v3.4.1](https://github.com/WorqHat/worqhat-python-sdk/compare/v3.4.0...v3.4.1)

## 3.4.0 (2025-07-31)

Full Changelog: [v0.0.1-alpha.0...v3.4.0](https://github.com/WorqHat/worqhat-python-sdk/compare/v0.0.1-alpha.0...v3.4.0)

### Features

* **api:** update via SDK Studio ([ce75dcc](https://github.com/WorqHat/worqhat-python-sdk/commit/ce75dcc31b078bab025560c5b196a4eecf7f1227))
* **api:** update via SDK Studio ([ec19825](https://github.com/WorqHat/worqhat-python-sdk/commit/ec19825709fbe7994a811981d5eb77630a0594ce))
* **api:** update via SDK Studio ([85ab7a2](https://github.com/WorqHat/worqhat-python-sdk/commit/85ab7a2e5c871ed5921ef6044c0f9926b939948d))
* **api:** update via SDK Studio ([1dca18a](https://github.com/WorqHat/worqhat-python-sdk/commit/1dca18acf452a7cc35c6e541d69b8a31ac90d29a))
* **api:** update via SDK Studio ([fbb6ab5](https://github.com/WorqHat/worqhat-python-sdk/commit/fbb6ab5d66c30d8ee3bd9328eab85304efd42614))


### Chores

* configure new SDK language ([c4d0258](https://github.com/WorqHat/worqhat-python-sdk/commit/c4d0258ea522088e0f6181228d1f04a64230b2d7))
* sync repo ([b2b1c38](https://github.com/WorqHat/worqhat-python-sdk/commit/b2b1c381aa08870a807c303164f6ff9689f8aea2))
* sync repo ([4766968](https://github.com/WorqHat/worqhat-python-sdk/commit/476696875aa8f142f588c4f016fa8110a0ec4e08))
* update SDK settings ([8d58885](https://github.com/WorqHat/worqhat-python-sdk/commit/8d5888563b3042cb684d9a4406a09edd2be22889))
* update SDK settings ([a1ff3c3](https://github.com/WorqHat/worqhat-python-sdk/commit/a1ff3c388307c293932c8ef069ae9ad3a03c393c))
* update SDK settings ([53e95ac](https://github.com/WorqHat/worqhat-python-sdk/commit/53e95acd14d9d4dd063c1c71a1ed0bcd9ab86e69))
* update SDK settings ([f5a73c5](https://github.com/WorqHat/worqhat-python-sdk/commit/f5a73c54db1e7d7d865701c79b13034a08ef5341))
* update SDK settings ([9ff0620](https://github.com/WorqHat/worqhat-python-sdk/commit/9ff062000f153819b5629a262395551a723b2382))
* update SDK settings ([d605766](https://github.com/WorqHat/worqhat-python-sdk/commit/d605766da0d10451b716cbf715c96e6b4ccf90b9))
* update SDK settings ([29497ca](https://github.com/WorqHat/worqhat-python-sdk/commit/29497ca3d7fc8232a9b0cc0fb70cb963c4624b33))
* update SDK settings ([e386fb8](https://github.com/WorqHat/worqhat-python-sdk/commit/e386fb86761c1ef06bd99b5a85b2fd6710d17737))
* update SDK settings ([0dbf509](https://github.com/WorqHat/worqhat-python-sdk/commit/0dbf5097e700966f2546ea967d0669eae280dbb9))
* update SDK settings ([64384f2](https://github.com/WorqHat/worqhat-python-sdk/commit/64384f2c7f05b7a54d89881791857068c10f1250))
* update SDK settings ([6c05440](https://github.com/WorqHat/worqhat-python-sdk/commit/6c05440a6f753841abdac7153f9bc0cb7688f7d9))
